Uses of Class
org.netbeans.api.diff.DiffController
Packages that use DiffController
-
Uses of DiffController in org.netbeans.api.diff
Methods in org.netbeans.api.diff that return DiffControllerModifier and TypeMethodDescriptionstatic DiffControllerDiffController.create(StreamSource base, StreamSource modified) Creates a Diff Controller for supplied left and right sources.static DiffControllerDiffController.createEnhanced(DiffController other, StreamSource base, StreamSource modified) Creates a Diff Controller for supplied left and right sources capable of creating enhanced UI.static DiffControllerDiffController.createEnhanced(StreamSource base, StreamSource modified) Creates a Diff Controller for supplied left and right sources capable of creating enhanced UI.Methods in org.netbeans.api.diff with parameters of type DiffControllerModifier and TypeMethodDescriptionstatic DiffControllerDiffController.createEnhanced(DiffController other, StreamSource base, StreamSource modified) Creates a Diff Controller for supplied left and right sources capable of creating enhanced UI.