Uses of Enum Class
org.netbeans.api.diff.DiffController.DiffPane
Packages that use DiffController.DiffPane
-
Uses of DiffController.DiffPane in org.netbeans.api.diff
Subclasses with type arguments of type DiffController.DiffPane in org.netbeans.api.diffModifier and TypeClassDescriptionstatic enumEnumerates Base (left) and Modified (right) panes of a Diff view for setLocation() methodMethods in org.netbeans.api.diff that return DiffController.DiffPaneModifier and TypeMethodDescriptionstatic DiffController.DiffPaneReturns the enum constant of this class with the specified name.static DiffController.DiffPane[]DiffController.DiffPane.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.netbeans.api.diff with parameters of type DiffController.DiffPaneModifier and TypeMethodDescriptionvoidDiffController.setLocation(DiffController.DiffPane pane, DiffController.LocationType type, int location) Ensure the requested location in the Diff view is visible on screen. -
Uses of DiffController.DiffPane in org.netbeans.spi.diff
Methods in org.netbeans.spi.diff with parameters of type DiffController.DiffPaneModifier and TypeMethodDescriptionvoidDiffControllerImpl.setLocation(DiffController.DiffPane pane, DiffController.LocationType type, int location) Ensure the requested location in the Diff view is visible on screen.