Uses of Class
org.netbeans.api.diff.StreamSource
Packages that use StreamSource
-
Uses of StreamSource in org.netbeans.api.diff
Methods in org.netbeans.api.diff that return StreamSourceModifier and TypeMethodDescriptionstatic StreamSourceStreamSource.createSource(String name, String title, String MIMEType, File file) Create the default implementation ofStreamSource, that has just reader and writer from/to a file.static StreamSourceStreamSource.createSource(String name, String title, String MIMEType, Reader r) Create the default implementation ofStreamSource, that has just reader and no writer.Methods in org.netbeans.api.diff with parameters of type StreamSourceModifier and TypeMethodDescriptionstatic DiffControllerDiffController.create(StreamSource base, StreamSource modified) Creates a Diff Controller for supplied left and right sources.Diff.createDiff(StreamSource s1, StreamSource s2) Creates single-window diff component that does not include any navigation controls and is controlled programatically via the returned DiffView interface.static DiffControllerDiffController.createEnhanced(DiffController other, StreamSource base, StreamSource modified) Creates a Diff Controller for supplied left and right sources capable of creating enhanced UI.static DiffControllerDiffController.createEnhanced(StreamSource base, StreamSource modified) Creates a Diff Controller for supplied left and right sources capable of creating enhanced UI. -
Uses of StreamSource in org.netbeans.spi.diff
Methods in org.netbeans.spi.diff with parameters of type StreamSourceModifier and TypeMethodDescriptionDiffVisualizer.createDiff(Difference[] diffs, StreamSource s1, StreamSource s2) Creates single-window diff component that does not include any navigation controls and is controlled programatically via the returned DiffView interface.abstract DiffControllerImplDiffControllerProvider.createDiffController(StreamSource base, StreamSource modified) Creates a Diff Controller for supplied left and right sources.DiffControllerProvider.createEnhancedDiffController(StreamSource base, StreamSource modified) Creates a Diff Controller for supplied left and right sources.abstract ComponentMergeVisualizer.createView(Difference[] diffs, StreamSource source1, StreamSource source2, StreamSource result) Show the visual representation of the merging process of two sources.